package com.bipt.intelligentapplicationorchestrationservice.gpu.cache.task;

import com.bipt.intelligentapplicationorchestrationservice.gpu.cache.CacheManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.event.ApplicationReadyEvent;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;

@Component
public class CacheInitTask {

    private final CacheManager cacheManager;

    @Value("${cache.init-batch-size:500}")
    private int batchSize;

    @Autowired
    public CacheInitTask(CacheManager cacheManager) {
        this.cacheManager = cacheManager;
    }

    /**
     * 应用启动后执行全量缓存加载
     * 使用@EventListener替代@PostConstruct确保数据库连接就绪
     */
    @EventListener(ApplicationReadyEvent.class)
    public void initCacheOnStartup() {
        try {
            cacheManager.loadFullCache(batchSize);
            System.out.println("✅ 缓存全量初始化完成 | Total loaded: " + cacheManager.getCacheCount());
        } catch (Exception e) {
            System.err.println("❌ 缓存初始化失败: " + e.getMessage());
            e.printStackTrace();
        }
    }
}