package com.bipt.intelligentapplicationorchestrationservice.gpu.config;

import com.bipt.intelligentapplicationorchestrationservice.gpu.model.entity.GpuResource;
import io.lettuce.core.ClientOptions;
import io.lettuce.core.SocketOptions;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.connection.RedisConnectionFactory;
import org.springframework.data.redis.connection.RedisPassword;
import org.springframework.data.redis.connection.RedisStandaloneConfiguration;
import org.springframework.data.redis.connection.lettuce.LettuceClientConfiguration;
import org.springframework.data.redis.connection.lettuce.LettuceConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.GenericJackson2JsonRedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;

import java.time.Duration;

@Configuration
public class RedisConfig {
    @Value("${spring.data.redis.host}")
    private String redisHost;

    @Value("${spring.data.redis.port}")
    private int redisPort;

    @Value("${spring.data.redis.username}")
    private String redisUsername;

    @Value("${spring.data.redis.password}")
    private String redisPassword;

    @Value("${spring.data.redis.ssl:false}")
    private boolean useSsl;

    @Bean
    public RedisConnectionFactory redisConnectionFactory() {
        // 1. 创建 SocketOptions
        SocketOptions socketOptions = SocketOptions.builder()
                .connectTimeout(Duration.ofSeconds(15))  // 连接超时
                .keepAlive(true)                        // 启用 TCP Keep-Alive
                .build();

        // 2. 构建 ClientOptions
        ClientOptions clientOptions = ClientOptions.builder()
                .socketOptions(socketOptions)
                .autoReconnect(true)                    // 启用自动重连
                .build();

        // 3. 集成到 Lettuce 配置
        LettuceClientConfiguration clientConfig = LettuceClientConfiguration.builder()
                .clientOptions(clientOptions)          // 注入 ClientOptions
                .commandTimeout(Duration.ofSeconds(30)) // 全局命令超时
                .build();
        RedisStandaloneConfiguration config = new RedisStandaloneConfiguration();
        config.setHostName(redisHost);
        config.setPort(redisPort);
        config.setUsername(redisUsername);  // Redis 6.0+ 支持用户名
        config.setPassword(RedisPassword.of(redisPassword));

//        LettuceClientConfiguration clientConfig = LettuceClientConfiguration.builder()
//                .commandTimeout(Duration.ofSeconds(30)) // 增加命令超时
//                .socketOptions(SocketOptions.builder()
//                        .connectTimeout(Duration.ofSeconds(15)) // TCP连接超时
//                        .build())
//                .build();

        return new LettuceConnectionFactory(config, clientConfig);
    }


//    @Bean
//    public RedisConnectionFactory redisConnectionFactory() {
//        RedisStandaloneConfiguration config = new RedisStandaloneConfiguration();
//        config.setPassword("");
//        return new LettuceConnectionFactory(config);
//    }

    @Bean
    public RedisTemplate<String, Object> redisTemplate(){
        RedisTemplate<String, Object> template = new RedisTemplate<>();
        //RedisTemplate<String, GpuResource> template = new RedisTemplate<>();
        template.setConnectionFactory(redisConnectionFactory());
        template.setKeySerializer(new StringRedisSerializer());
        template.setValueSerializer(new GenericJackson2JsonRedisSerializer());
        return template;
    }
}
