package com.bipt.intelligentapplicationorchestrationservice.gpu.controller;

import com.bipt.intelligentapplicationorchestrationservice.gpu.model.dto.GpuCreateDTO;
import com.bipt.intelligentapplicationorchestrationservice.gpu.model.dto.GpuResponseDTO;
import com.bipt.intelligentapplicationorchestrationservice.gpu.model.dto.GpuUpdateDTO;
import com.bipt.intelligentapplicationorchestrationservice.gpu.model.vo.ResponseVO;
import com.bipt.intelligentapplicationorchestrationservice.gpu.service.GpuManageService;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping
public class GpuResourceController {
    @Autowired
    private GpuManageService gpuManageService;

    @PostMapping
    public ResponseVO addGpu(@Valid @RequestBody GpuCreateDTO dto){
        return gpuManageService.createGpuResource(dto);
    }

    @DeleteMapping("/{gpuId}")
    public ResponseVO removeGpu(@PathVariable("gpuId") Long gpuId){
        return gpuManageService.deleteGpuResource(gpuId);
    }

    @PutMapping("/{gpuId}")
    public void updateGpuResource(
            @PathVariable Long gpuId,
            @Valid @RequestBody GpuUpdateDTO dto){
        dto.setGPUId(gpuId);
        gpuManageService.updateGpuResource(dto);
    }

    @GetMapping("/search")
    public ResponseVO<List<GpuResponseDTO>> searchGpuResources(
            @RequestParam(required = false) String model,
            @RequestParam(required = false) Integer memorySize,
            @RequestParam(required = false) String ip){

        List<GpuResponseDTO> resources = gpuManageService.searchByCriteria(model, memorySize,ip);

        return ResponseVO.success(resources);
    }
}
